use strict;
use warnings;

use Test::More tests => 1;

BEGIN {
    use_ok( 'Test::XML::Order' );
}

# Local Variables:
# mode: cperl
# cperl-indent-level: 4
# indent-tabs-mode: nil
# End:
# vim: set ai et sw=4 syntax=perl :


